// ===============================================
// File:		      GLsettings.H
// Description:		
// Version 1:
// Current:
// Author(s):		Thomas Kern
// ===============================================

/*
 * Copyright (C) 1997-1998  Thomas Kern
 */

#ifndef GLSETTINGS_H
#define GLSETTINGS_H

//=====================================================================
//	INCLUDES AND DEFINES
//=====================================================================
//
#include <math.h>

#ifdef _WIN32
  // speziell fuer bestimmte Visual C++ Warnungen
  #pragma warning( disable : 4244 ) // double zu float bei += etc.
  #pragma warning( disable : 4305 ) // double zu float bei += etc.
  #include <windows.h>
#endif

#include <GL/gl.h>
#include <GL/glu.h>

#define MAX_TRANSFORMS 20

//=====================================================================
//	STEUERUNG DES OPENGL-STATUS
//=====================================================================
//
class OpenGLState
{
  public:
    OpenGLState(int winWidth, int winHeight);
    ~OpenGLState();

    void Reset();
    void InitFromFile();
    void CopyInitValues();

    void SetPerspective(int newWidth, int newHeight);
    void SetPlanes(GLdouble nearP, GLdouble farP) {
      if(nearP) // passing NULL changes nothing
        nearPlane = nearP;
      if(farP)
        farPlane = farP;
    };
    void SetAngle(GLdouble angle) {
      if(angle)
        ViewingAngle = angle;
    };

    // der Betrachter steht im Ursprung
    void ClearEyeMovement();
    // der Betrachter bewegt sich von seiner Position weg
    void SetEyeTransformation(int pos, GLfloat point[3]);
    // der Betrachter dreht sich um seine Position
    void SetEyeRotation(int pos, GLfloat angle, GLfloat vector[3]);


  private:
    GLint     initHeight,    initWidth;
    GLint     currentHeight, currentWidth;
    GLdouble  initAngle,     initAspect;
    GLdouble  ViewingAngle,  WindowAspect;
    GLdouble  initNearPlane, initFarPlane;
    GLdouble  nearPlane,     farPlane;

    int       eyeMoveCount;
    enum {skip, rot, trans} moveEye;
    GLfloat   nextMove[MAX_TRANSFORMS][5]; // moveEye, vector, angle
};

// --------------------------------------------------------------------
#endif // GLSETTINGS_H